@@ -5,10 +5,10 @@ from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 
 __all__ = ['Sale', 'SaleLine']
-__metaclass__ = PoolMeta
 
 
 class Sale:
+    __metaclass__ = PoolMeta
     __name__ = 'sale.sale'
 
     def is_done(self):
@@ -60,6 +60,7 @@ class Sale:
 
 
 class SaleLine:
+    __metaclass__ = PoolMeta
     __name__ = 'sale.line'
 
     purchase_request = fields.Many2One('purchase.request', 'Purchase Request',
@@ -126,7 +127,7 @@ class SaleLine:
 
         product = self.product
         supplier, purchase_date = Request.find_best_supplier(product,
-            self.delivery_date)
+            self.shipping_date)
         uom = product.purchase_uom or product.default_uom
         quantity = Uom.compute_qty(self.unit, self.quantity, uom)
         return Request(
@@ -137,7 +138,7 @@ class SaleLine:
             computed_quantity=quantity,
             computed_uom=uom,
             purchase_date=purchase_date,
-            supply_date=self.delivery_date,
+            supply_date=self.shipping_date,
             company=self.sale.company,
             warehouse=self.warehouse,
             origin=self.sale,
